image_compare_slider library
Easily compare two images with a slider, with zoom, pan and rotation.
Classes
- DividerLineStyle
-
Describes how the divider line of an
ImageCompareSlideris stroked. - ImageCompareSlider
- A Flutter widget that allows you to compare two images.
- ImageCompareSliderController
-
Holds and drives the interactive state of an
ImageCompareSlider.
Enums
- SliderDirection
- Slider direction.
Typedefs
- HandleBuilder = Widget Function(BuildContext context, double position, bool portrait)
- Builder for a fully custom handle widget.